# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tensorboard/uploader/proto/export_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tensorboard.uploader.proto import blob_pb2 as tensorboard_dot_uploader_dot_proto_dot_blob__pb2
from tensorboard.uploader.proto import experiment_pb2 as tensorboard_dot_uploader_dot_proto_dot_experiment__pb2
from tensorboard.compat.proto import summary_pb2 as tensorboard_dot_compat_dot_proto_dot_summary__pb2
from tensorboard.compat.proto import tensor_pb2 as tensorboard_dot_compat_dot_proto_dot_tensor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tensorboard/uploader/proto/export_service.proto',
  package='tensorboard.service',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n/tensorboard/uploader/proto/export_service.proto\x12\x13tensorboard.service\x1a\x1fgoogle/protobuf/timestamp.proto\x1a%tensorboard/uploader/proto/blob.proto\x1a+tensorboard/uploader/proto/experiment.proto\x1a&tensorboard/compat/proto/summary.proto\x1a%tensorboard/compat/proto/tensor.proto\"\xad\x01\n\x18StreamExperimentsRequest\x12\x32\n\x0eread_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x03\x12=\n\x10\x65xperiments_mask\x18\x04 \x01(\x0b\x32#.tensorboard.service.ExperimentMask\"i\n\x19StreamExperimentsResponse\x12\x16\n\x0e\x65xperiment_ids\x18\x01 \x03(\t\x12\x34\n\x0b\x65xperiments\x18\x02 \x03(\x0b\x32\x1f.tensorboard.service.Experiment\"h\n\x1bStreamExperimentDataRequest\x12\x15\n\rexperiment_id\x18\x01 \x01(\t\x12\x32\n\x0eread_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe4\x05\n\x1cStreamExperimentDataResponse\x12\x10\n\x08tag_name\x18\x01 \x01(\t\x12\x10\n\x08run_name\x18\x02 \x01(\t\x12\x32\n\x0ctag_metadata\x18\x03 \x01(\x0b\x32\x1c.tensorboard.SummaryMetadata\x12P\n\x06points\x18\x04 \x01(\x0b\x32>.tensorboard.service.StreamExperimentDataResponse.ScalarPointsH\x00\x12Q\n\x07tensors\x18\x05 \x01(\x0b\x32>.tensorboard.service.StreamExperimentDataResponse.TensorPointsH\x00\x12^\n\x0e\x62lob_sequences\x18\x06 \x01(\x0b\x32\x44.tensorboard.service.StreamExperimentDataResponse.BlobSequencePointsH\x00\x1a]\n\x0cScalarPoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06values\x18\x03 \x03(\x01\x1aw\n\x0cTensorPoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x06values\x18\x03 \x03(\x0b\x32\x18.tensorboard.TensorProto\x1a\x86\x01\n\x12\x42lobSequencePoints\x12\r\n\x05steps\x18\x01 \x03(\x03\x12.\n\nwall_times\x18\x02 \x03(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x06values\x18\x03 \x03(\x0b\x32!.tensorboard.service.BlobSequenceB\x06\n\x04\x64\x61ta\"(\n\x15StreamBlobDataRequest\x12\x0f\n\x07\x62lob_id\x18\x01 \x01(\t\"g\n\x16StreamBlobDataResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x13\n\x0b\x66inal_chunk\x18\x04 \x01(\x08\x12\x14\n\x0c\x66inal_crc32c\x18\x05 \x01(\x07J\x04\x08\x03\x10\x04\x32\x84\x03\n\x1aTensorBoardExporterService\x12v\n\x11StreamExperiments\x12-.tensorboard.service.StreamExperimentsRequest\x1a..tensorboard.service.StreamExperimentsResponse\"\x00\x30\x01\x12\x7f\n\x14StreamExperimentData\x12\x30.tensorboard.service.StreamExperimentDataRequest\x1a\x31.tensorboard.service.StreamExperimentDataResponse\"\x00\x30\x01\x12m\n\x0eStreamBlobData\x12*.tensorboard.service.StreamBlobDataRequest\x1a+.tensorboard.service.StreamBlobDataResponse\"\x00\x30\x01\x62\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_blob__pb2.DESCRIPTOR,tensorboard_dot_uploader_dot_proto_dot_experiment__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_summary__pb2.DESCRIPTOR,tensorboard_dot_compat_dot_proto_dot_tensor__pb2.DESCRIPTOR,])




_STREAMEXPERIMENTSREQUEST = _descriptor.Descriptor(
  name='StreamExperimentsRequest',
  full_name='tensorboard.service.StreamExperimentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_timestamp', full_name='tensorboard.service.StreamExperimentsRequest.read_timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='tensorboard.service.StreamExperimentsRequest.user_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='tensorboard.service.StreamExperimentsRequest.limit', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiments_mask', full_name='tensorboard.service.StreamExperimentsRequest.experiments_mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=442,
)


_STREAMEXPERIMENTSRESPONSE = _descriptor.Descriptor(
  name='StreamExperimentsResponse',
  full_name='tensorboard.service.StreamExperimentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_ids', full_name='tensorboard.service.StreamExperimentsResponse.experiment_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='experiments', full_name='tensorboard.service.StreamExperimentsResponse.experiments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=549,
)


_STREAMEXPERIMENTDATAREQUEST = _descriptor.Descriptor(
  name='StreamExperimentDataRequest',
  full_name='tensorboard.service.StreamExperimentDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='experiment_id', full_name='tensorboard.service.StreamExperimentDataRequest.experiment_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_timestamp', full_name='tensorboard.service.StreamExperimentDataRequest.read_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=551,
  serialized_end=655,
)


_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS = _descriptor.Descriptor(
  name='ScalarPoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.ScalarPoints.values', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1132,
)

_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS = _descriptor.Descriptor(
  name='TensorPoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.TensorPoints.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1253,
)

_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS = _descriptor.Descriptor(
  name='BlobSequencePoints',
  full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='steps', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.steps', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wall_times', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.wall_times', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1390,
)

_STREAMEXPERIMENTDATARESPONSE = _descriptor.Descriptor(
  name='StreamExperimentDataResponse',
  full_name='tensorboard.service.StreamExperimentDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag_name', full_name='tensorboard.service.StreamExperimentDataResponse.tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='run_name', full_name='tensorboard.service.StreamExperimentDataResponse.run_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tag_metadata', full_name='tensorboard.service.StreamExperimentDataResponse.tag_metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='tensorboard.service.StreamExperimentDataResponse.points', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tensors', full_name='tensorboard.service.StreamExperimentDataResponse.tensors', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_sequences', full_name='tensorboard.service.StreamExperimentDataResponse.blob_sequences', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS, _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS, _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='tensorboard.service.StreamExperimentDataResponse.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=658,
  serialized_end=1398,
)


_STREAMBLOBDATAREQUEST = _descriptor.Descriptor(
  name='StreamBlobDataRequest',
  full_name='tensorboard.service.StreamBlobDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob_id', full_name='tensorboard.service.StreamBlobDataRequest.blob_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1440,
)


_STREAMBLOBDATARESPONSE = _descriptor.Descriptor(
  name='StreamBlobDataResponse',
  full_name='tensorboard.service.StreamBlobDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='tensorboard.service.StreamBlobDataResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='tensorboard.service.StreamBlobDataResponse.offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_chunk', full_name='tensorboard.service.StreamBlobDataResponse.final_chunk', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='final_crc32c', full_name='tensorboard.service.StreamBlobDataResponse.final_crc32c', index=3,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1545,
)

_STREAMEXPERIMENTSREQUEST.fields_by_name['read_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTSREQUEST.fields_by_name['experiments_mask'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENTMASK
_STREAMEXPERIMENTSRESPONSE.fields_by_name['experiments'].message_type = tensorboard_dot_uploader_dot_proto_dot_experiment__pb2._EXPERIMENT
_STREAMEXPERIMENTDATAREQUEST.fields_by_name['read_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.fields_by_name['values'].message_type = tensorboard_dot_compat_dot_proto_dot_tensor__pb2._TENSORPROTO
_STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.fields_by_name['wall_times'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.fields_by_name['values'].message_type = tensorboard_dot_uploader_dot_proto_dot_blob__pb2._BLOBSEQUENCE
_STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS.containing_type = _STREAMEXPERIMENTDATARESPONSE
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tag_metadata'].message_type = tensorboard_dot_compat_dot_proto_dot_summary__pb2._SUMMARYMETADATA
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'].message_type = _STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'].message_type = _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'].message_type = _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['points'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['tensors'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
_STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data'].fields.append(
  _STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'])
_STREAMEXPERIMENTDATARESPONSE.fields_by_name['blob_sequences'].containing_oneof = _STREAMEXPERIMENTDATARESPONSE.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['StreamExperimentsRequest'] = _STREAMEXPERIMENTSREQUEST
DESCRIPTOR.message_types_by_name['StreamExperimentsResponse'] = _STREAMEXPERIMENTSRESPONSE
DESCRIPTOR.message_types_by_name['StreamExperimentDataRequest'] = _STREAMEXPERIMENTDATAREQUEST
DESCRIPTOR.message_types_by_name['StreamExperimentDataResponse'] = _STREAMEXPERIMENTDATARESPONSE
DESCRIPTOR.message_types_by_name['StreamBlobDataRequest'] = _STREAMBLOBDATAREQUEST
DESCRIPTOR.message_types_by_name['StreamBlobDataResponse'] = _STREAMBLOBDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamExperimentsRequest = _reflection.GeneratedProtocolMessageType('StreamExperimentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTSREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentsRequest)
  })
_sym_db.RegisterMessage(StreamExperimentsRequest)

StreamExperimentsResponse = _reflection.GeneratedProtocolMessageType('StreamExperimentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTSRESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentsResponse)
  })
_sym_db.RegisterMessage(StreamExperimentsResponse)

StreamExperimentDataRequest = _reflection.GeneratedProtocolMessageType('StreamExperimentDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMEXPERIMENTDATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataRequest)
  })
_sym_db.RegisterMessage(StreamExperimentDataRequest)

StreamExperimentDataResponse = _reflection.GeneratedProtocolMessageType('StreamExperimentDataResponse', (_message.Message,), {

  'ScalarPoints' : _reflection.GeneratedProtocolMessageType('ScalarPoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_SCALARPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.ScalarPoints)
    })
  ,

  'TensorPoints' : _reflection.GeneratedProtocolMessageType('TensorPoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_TENSORPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.TensorPoints)
    })
  ,

  'BlobSequencePoints' : _reflection.GeneratedProtocolMessageType('BlobSequencePoints', (_message.Message,), {
    'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE_BLOBSEQUENCEPOINTS,
    '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
    # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse.BlobSequencePoints)
    })
  ,
  'DESCRIPTOR' : _STREAMEXPERIMENTDATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamExperimentDataResponse)
  })
_sym_db.RegisterMessage(StreamExperimentDataResponse)
_sym_db.RegisterMessage(StreamExperimentDataResponse.ScalarPoints)
_sym_db.RegisterMessage(StreamExperimentDataResponse.TensorPoints)
_sym_db.RegisterMessage(StreamExperimentDataResponse.BlobSequencePoints)

StreamBlobDataRequest = _reflection.GeneratedProtocolMessageType('StreamBlobDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOBDATAREQUEST,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamBlobDataRequest)
  })
_sym_db.RegisterMessage(StreamBlobDataRequest)

StreamBlobDataResponse = _reflection.GeneratedProtocolMessageType('StreamBlobDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBLOBDATARESPONSE,
  '__module__' : 'tensorboard.uploader.proto.export_service_pb2'
  # @@protoc_insertion_point(class_scope:tensorboard.service.StreamBlobDataResponse)
  })
_sym_db.RegisterMessage(StreamBlobDataResponse)



_TENSORBOARDEXPORTERSERVICE = _descriptor.ServiceDescriptor(
  name='TensorBoardExporterService',
  full_name='tensorboard.service.TensorBoardExporterService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1548,
  serialized_end=1936,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamExperiments',
    full_name='tensorboard.service.TensorBoardExporterService.StreamExperiments',
    index=0,
    containing_service=None,
    input_type=_STREAMEXPERIMENTSREQUEST,
    output_type=_STREAMEXPERIMENTSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StreamExperimentData',
    full_name='tensorboard.service.TensorBoardExporterService.StreamExperimentData',
    index=1,
    containing_service=None,
    input_type=_STREAMEXPERIMENTDATAREQUEST,
    output_type=_STREAMEXPERIMENTDATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='StreamBlobData',
    full_name='tensorboard.service.TensorBoardExporterService.StreamBlobData',
    index=2,
    containing_service=None,
    input_type=_STREAMBLOBDATAREQUEST,
    output_type=_STREAMBLOBDATARESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_TENSORBOARDEXPORTERSERVICE)

DESCRIPTOR.services_by_name['TensorBoardExporterService'] = _TENSORBOARDEXPORTERSERVICE

# @@protoc_insertion_point(module_scope)
